config

package
v0.0.0-...-5c9a59b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 26, 2023 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {
	Console Console
	Lists   []List
	Net     Net
}

Config is the main configuration struct.

func Parse

func Parse(cfile string) (Config, error)

Parse reads a TOML config from cfile.

type Console

type Console struct {
	// Enabled toggles whether the console is enabled.
	Enabled bool
}

Console is the configuration struct for the yaps console.

type List

type List struct {
	// Player is the TCP host:port string for the mounted playd instance.
	Player string
}

List is the configuration struct for a yaps list node.

type Net

type Net struct {
	// Enabled toggles whether the net server is enabled.
	Enabled bool
	// Host is the TCP host:port string for the net server.
	Host string
	// Log toggles whether the net server logs to stderr.
	Log bool
}

Net is the configuration struct for the yaps net server.

Jump to